pub struct JwtLayer<Claim, F = DecodingKey> { /* private fields */ }Expand description
Layer to validate JWT tokens with a decoding key. Valid claims are added to the request extension
It can also be used with tonic. See: https://github.com/hyperium/tonic/blob/master/examples/src/tower/server.rs
Implementations
Sourceimpl<Claim, F: DecodingKeyFn> JwtLayer<Claim, F>
impl<Claim, F: DecodingKeyFn> JwtLayer<Claim, F>
Sourcepub fn new(validation: Validation, decoding_key_fn: F) -> Self
pub fn new(validation: Validation, decoding_key_fn: F) -> Self
Create a new layer to validate JWT tokens with the given decoding key Tokens will only be accepted if they pass the validation